************************************************************************************************************
************************************************************************************************************
**** Project: Kenyan list experiment paper 
**** Authors: Solomon Zena Walelign
**** Version: August 7, 2021
**** Purpose: produce study site area
************************************************************************************************************
************************************************************************************************************
//== GLOBAL MACROS WITH RELEVANT DIRECTORIES ===========================================================================
// directories incuding data, processed tables, processed figures and other output
quietly include "`c(pwd)'/env_setup/env.do" 
quietly include "`c(pwd)'/data_processing/Data_processing.do" 
assert "${data_path}" != "" & "${table_path}" != "" & "${figure_path}" != "" // should be defined
set varabbrev on

//==preparing the survey data to extract household location
drop if attrition==1
keep if survey_year=="21"
generate types1="Intervention households" if types==1 
replace types1="Non-intervention households" if types==2 

save "${data_path}/KDRDIP_supplementary baseline household survey datasets_stayers.dta", replace 

//==preparing the data to extract the location of sublocations
import excel "${data_path}/KDRDIP SUB-LOCATIONS GPS.xlsx", clear sheet("FGD Data2") firstrow
rename (CaptureHouseholdGPSLatitude CaptureHouseholdGPSLongitude) (Latitude Longitude)
encode types, gen (types_encoded)
save "${data_path}/KDRDIP SUB-LOCATIONS GPS.dta", replace 


/*
//==reading the level three dataset================================================================ 
shp2dta using "${data_path}/gadm41_KEN_shp/gadm41_KEN_3", database(Kenya_data_3) coordinates(Kenya_coord_3) genid(Kenya_ID_3) replace 

//++reading the data 
use Kenya_data_3, clear 

//==reading level 2 dataset ============================================================================ 
shp2dta using "${data_path}/gadm41_KEN_shp/gadm41_KEN_2", database(Kenya_data_2) coordinates(Kenya_coord_2) genid(Kenya_ID_2) replace 

//++reading the data 
use Kenya_data_2, clear 
*/

//==reading level 1 dataset ===================================================================
cap which shp2dta 
if _rc ssc install shp2dta

cap which spmap 
if _rc ssc install spmap
 
shp2dta using "${data_path}/gadm41_KEN_shp/gadm41_KEN_1", database(Kenya_data_1) coordinates(Kenya_coord_1) genid(Kenya_ID_1) replace 

use Kenya_coord_1, clear 

//++reading the data - FIGURE 1
use Kenya_data_1, clear 
gen study_county=1 if NAME_1=="Garissa" | NAME_1=="Tana River" | NAME_1=="Isiolo" | NAME_1=="Turkana" | NAME_1=="Wajir" 

spmap study_county using Kenya_coord_1, id(Kenya_ID_1) fcolor(ebg) ndfcolor(white) legend(ring(1) position(8) size(small) label(2 "Study counties")) mosize(vvvthin) point(data("${data_path}/Refugee_camp_location.dta") xcoord(Longitude) ycoord(Latitude) shape(T) fcolor(red) ocolor(red) osize(*2) size(*0.4) legenda(on) leglabel("Refugee camps")) scalebar(units(250) scale(111.1) xpos(-10) ypos(90) label(Kilometers)) 

//++reading the data - FIGURE 2
use Kenya_data_1, clear 
gen study_county=1 if NAME_1=="Garissa" | NAME_1=="Tana River" | NAME_1=="Isiolo" | NAME_1=="Turkana" | NAME_1=="Wajir" 
spmap study_county using Kenya_coord_1, id(Kenya_ID_1) fcolor(ebg) ndfcolor(white) legend(ring(1) position(8) size(small) label(2 "Study counties")) mosize(vvvthin) point(data("${data_path}/KDRDIP SUB-LOCATIONS GPS") xcoord(Longitude) ycoord(Latitude) fcolor(green red) by(types_encoded) shape(T o)ocolor(green red) osize(*0.01 *0.01) size(*0.4 *0.4) legenda(on) leglabel ("Intervention sublocations" "Non-intervention sublocations")) scalebar(units(250) scale(111.1) xpos(-10) ypos(90) label(Kilometers))
		
//++reading the data - FIGURE 3
use Kenya_data_1, clear 
gen study_county=1 if NAME_1=="Garissa" | NAME_1=="Tana River" | NAME_1=="Isiolo" | NAME_1=="Turkana" | NAME_1=="Wajir" 
spmap study_county using Kenya_coord_1, id(Kenya_ID_1) fcolor(ebg) ndfcolor(white) legend(ring(1) position(8) size(small) label(2 "Study counties")) mosize(vvvthin) point(data("${data_path}/KDRDIP_supplementary baseline household survey datasets_stayers.dta") xcoord(GPSLongitude) ycoord(GPSLatitude) fcolor(green red) by(types) shape(T o) ocolor(green red) osize(*0.01 *0.01) size(*0.4 *0.4) legenda(on) leglabel(1 "Intervention households" 2 "Non-intervention households")) scalebar(units(250) scale(111.1) xpos(-10) ypos(90) label(Kilometers))

/*
//////////////////////////////////////////////
use Kenya_data_1, clear 
gen study_county=1 if NAME_1=="Garissa" | NAME_1=="Tana River" | NAME_1=="Isiolo" | NAME_1=="Turkana" | NAME_1=="Wajir" 
spmap study_county using Kenya_coord_1, id(Kenya_ID_1) fcolor(ebg) ndfcolor(white) legend(ring(1) position(8) size(small) label(2 "Study counties")) mosize(vvvthin) point(data("${data_path}/KDRDIP_supplementary baseline household survey datasets_treatment.dta") xcoord(GPSLongitude) ycoord(GPSLatitude) fcolor(green red) by(types) ocolor(green red) osize(*0.01 *0.01) size(*0.4 *0.4) legenda(on) leglabel("Treatment households" "Control households")) point(data("${data_path}/KDRDIP_supplementary baseline household survey datasets_control.dta") xcoord(GPSLongitude) ycoord(GPSLatitude) fcolor(green red) by(types) ocolor(green red) osize(*0.01 *0.01) size(*0.4 *0.4) legenda(on) leglabel("Treatment households" "Control households"))scalebar(units(250) scale(111.1) xpos(-10) ypos(90) label(Kilometers))

////////////////////////////////////////////////////////
use Kenya_data_2, clear 
gen study_subcounty=1 if NAME_2==" Fafi" | NAME_2=="Lagdera" | NAME_2=="Daadab" | NAME_2=="Turkana West" | NAME_2=="Wajir South"

spmap study_subcounty using Kenya_coord_2, id(Kenya_ID_2) fcolor(ebg) ndfcolor(white) legend(ring(1) position(8) size(small) label(2 "Treament subcounties")) mosize(vvvthin) scalebar(units(250) scale(111.1) xpos(-10) ypos(90) label(Kilometers))






spmap study_subcounty using Kenya_coord_2, id(Kenya_ID_2) fcolor(ebg) ndfcolor(white) legend(ring(1) position(8) size(small) label(2 "Treament subcounties")) mosize(vvvthin) scalebar(units(250) scale(111.1) xpos(-10) ypos(90) label(Kilometers))
*/
