******************************************************************************************************************************************************************************************************************************************************************************************************************************************************************
//APPENDICES==========================================================================================================
**********************************************************************************************************************

//== GLOBAL MACROS WITH RELEVANT DIRECTORIES ===========================================================================
// directories incuding data, processed tables, processed figures and other output
quietly include "`c(pwd)'/env_setup/env.do" 
assert "${data_path}" != "" & "${table_path}" != "" & "${figure_path}" != "" // should be defined

//====================================================================================================================
//reading the dataset for all the appendices
quietly include "`c(pwd)'/data_processing/data_processing.do" 

//====================================================================================================================
//APPENDIX B - Balance test between the treatment and control groups
*if _rc ssc install asdoc
*ssc install asdoc, replace 

cd "${table_path}" 
asdoc ttest child_0_6 if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) replace save(Appendix_B)
asdoc ttest child_7_13 if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend save(Appendix_B)
asdoc ttest adult_female_14_65 if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend save(Appendix_B)
asdoc ttest adult_male_14_65 if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend save(Appendix_B)
asdoc ttest elder_65 if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend save(Appendix_B)
asdoc ttest women_25_60_educ_mean if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend save(Appendix_B)
asdoc ttest women_25_60_age_mean if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend
asdoc ttest women_25_60_atte_scho_num if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend save(Appendix_B)
asdoc ttest women_25_60_housewif_num if info_treat_stat==0|info_treat_stat==1, by(info_treat_stat) rowappend save(Appendix_B)

//===================================================================================================================
//APPENDIX I - summary statistics of women's understanding of the script
cd "${table_path}" 
local Scrip_understand "Scrip_Under_encou_part Scrip_Under_benef_you Scrip_Under_benef_fam Scrip_Under_benef_com Scrip_Under_pho_comfac"
asdoc tab Scrip_Under_encou_part, replace 
foreach var of varlist Scrip_Under_benef_you Scrip_Under_benef_fam Scrip_Under_benef_com Scrip_Under_pho_comfac {
	asdoc tab `var', save save(Appendix_I)
}


//===================================================================================================================
//APPENDIX J - Descriptive statistics of variables considered in the model 
cd "${table_path}" 
asdoc sum post_like_part prior_like_part KDRDIP_heard_before_yes info_treat_stat info_treat_stat_act_dum info_treat_stat_act_cou Per_take_oppo Per_ben_wom Per_ben_fam Per_ben_com Per_cont_comFaci perception_index child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num if info_treat_stat==0|info_treat_stat==1, replace save(Appendix_J)

//======================================================================================================
//APPENDIX K - Information treatment takeup as a count - OLS
*1. only informaton treatment 
eststo clear
reg post_like_part_log info_treat_stat_act_cou if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m1
estadd local Sublocation_FE "No"
estadd local Other_controls "No"

*2. information treatment and sublocation fixed effects
reg post_like_part_log info_treat_stat_act_cou i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m2 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*3.information treatment, sublocation fixed effects, and prior likelihood of participation
reg post_like_part_log info_treat_stat_act_cou prior_like_part_log i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m3 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*4. information treatment, sublocation fixed effects, prior likelihood of participation, and interaction between prior particpation and treatment
reg post_like_part_log info_treat_stat_act_cou prior_like_part_log ac_treat_cou_prior_like_part_log i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m4 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
 
*5. information treatment, sublocation fixed effects, and heard before
reg post_like_part_log info_treat_stat_act_cou KDRDIP_heard_before_yes i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m5 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"


*6. information treatment, sublocation fixed effects, heard before, and interaction between treatment and heard before
reg post_like_part_log info_treat_stat_act_cou KDRDIP_heard_before_yes ac_treat_cou_heard_before i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m6
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*7. information treatment, sublocation fixed effects, heard before, interaction between treatment and heard before, prior likelihood of particpiation, and interaction between treatment and prior likelihood of participation
reg post_like_part_log info_treat_stat_act_cou prior_like_part_log ac_treat_cou_prior_like_part_log KDRDIP_heard_before_yes ac_treat_cou_heard_before i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m7 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"


*8. other controls 
reg post_like_part_log info_treat_stat_act_cou prior_like_part_log ac_treat_cou_prior_like_part_log KDRDIP_heard_before_yes ac_treat_cou_heard_before child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m8 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "${table_path}/Appendix K: Regression_posterior_likelihood of particpation_actual treatment_count.rtf", keep (info_treat_stat_act_cou prior_like_part_log ac_treat_cou_prior_like_part_log KDRDIP_heard_before_yes ac_treat_cou_heard_before) s(N Sublocation_FE Other_controls) mtitle ("" "" "" "" "" "" "" "") replace $tabOpt starlevels( * 0.10 ** 0.05 *** 0.010)

//======================================================================================================
//APPENDIX L - Information treatment takeup as a count - IV
*1. only informaton treatment 
eststo clear 
ivregress 2sls post_like_part_log (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m1
estadd local Sublocation_FE "No"
estadd local Other_controls "No"

*2. information treatment and sublocation fixed effects
ivregress 2sls post_like_part_log i.sublocation (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation)
estimates store m2 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*3.information treatment, sublocation fixed effects, and prior likelihood of participation
ivregress 2sls post_like_part_log prior_like_part_log i.sublocation (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m3
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*4. information treatment, sublocation fixed effects, prior likelihood of participation, and interaction between prior particpation and treatment
ivregress 2sls post_like_part_log prior_like_part_log i.sublocation (info_treat_stat_act_cou ac_treat_cou_prior_like_part_log=info_treat_stat treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m4
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"


*5. information treatment, sublocation fixed effects, and heard before
ivregress 2sls post_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_cou=info_treat_stat ) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m5
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*6. information treatment, sublocation fixed effects, heard before, and interaction between treatment and heard before
ivregress 2sls post_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_cou ac_treat_cou_heard_before=info_treat_stat treatment_heard_before) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m6
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*7. information treatment, sublocation fixed effects, heard before, interaction between treatment and heard before, prior likelihood of particpiation, and interaction between treatment and prior likelihood of participation
ivregress 2sls post_like_part_log prior_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_cou ac_treat_cou_heard_before ac_treat_cou_prior_like_part_log=info_treat_stat treatment_prior_like_part_log treatment_heard_before) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m7
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*8. other controls 
ivregress 2sls post_like_part_log prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_cou ac_treat_cou_heard_before ac_treat_cou_prior_like_part_log=info_treat_stat treatment_heard_before treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m8
estadd local Sublocation_FE "Yes", replace   
estadd local Other_controls "Yes", replace 

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "${table_path}/Appendix L: IVRegression_posterior_likelihood of particpation_actual treatment_count.rtf", keep (info_treat_stat_act_cou prior_like_part_log ac_treat_cou_prior_like_part_log KDRDIP_heard_before_yes ac_treat_cou_heard_before) s(N Sublocation_FE Other_controls) mtitle ("" "" "" "" "" "" "" "") replace $tabOpt starlevels( * 0.10 ** 0.05 *** 0.010)
//========================================================================================================
//APPENDIX N - impact on perception - actual treatment - count============================================
//OLS
*1. only informaton treatment
eststo clear 
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat_act_cou if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store `var'_BOAT 
}

*2. information treatment and sublocation fixed effects
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat_act_cou i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store `var'_SOAT
}

*8. other controls 
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store `var'_OOAT
}

//2sls 
*1. only informaton treatment
foreach var in $perception_log_perception_index {
ivregress 2sls `var' (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store `var'_BIV 	
}

*2. information treatment and sublocation fixed effects
foreach var in $perception_log_perception_index {
ivregress 2sls `var' i.sublocation (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store `var'_SIV 	
}

*8. other controls 
foreach var in $perception_log_perception_index {
ivregress 2sls `var' prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store `var'_OIV	
}

global Per_take_oppo_est "Per_take_oppo_log_BOAT Per_take_oppo_log_SOAT Per_take_oppo_log_OOAT Per_take_oppo_log_BIV Per_take_oppo_log_SIV Per_take_oppo_log_OIV"

global Per_ben_wom_est "Per_ben_wom_log_BOAT Per_ben_wom_log_SOAT Per_ben_wom_log_OOAT Per_ben_wom_log_BIV Per_ben_wom_log_SIV Per_ben_wom_log_OIV"

global Per_ben_fam_est "Per_ben_fam_log_BOAT Per_ben_fam_log_SOAT Per_ben_fam_log_OOAT Per_ben_fam_log_BIV Per_ben_fam_log_SIV Per_ben_fam_log_OIV"

global Per_ben_com_est "Per_ben_com_log_BOAT Per_ben_com_log_SOAT Per_ben_com_log_OOAT Per_ben_com_log_BIV Per_ben_com_log_SIV Per_ben_com_log_OIV"

global Per_cont_comFaci_est "Per_cont_comFaci_log_BOAT Per_cont_comFaci_log_SOAT Per_cont_comFaci_log_OOAT Per_cont_comFaci_log_BIV Per_cont_comFaci_log_SIV Per_cont_comFaci_log_OIV"

global perception_index_est "perception_index_BOAT perception_index_SOAT perception_index_OOAT perception_index_BIV perception_index_SIV perception_index_OIV"

*PANEL A
esttab $Per_take_oppo_est using "${table_path}/Appendix N: Reg_perception_actual_treatment_count.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) $tabOpt replace starlevels( * 0.10 ** 0.05 *** 0.010) title(PANEL A)

*PANEL B
esttab $Per_ben_wom_est using "${table_path}/Appendix N: Reg_perception_actual_treatment_count.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title(PANEL B)

*PANEL C
esttab $Per_ben_fam_est using "${table_path}/Appendix N: Reg_perception_actual_treatment_count.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title(PANEL C)

*PANEL D
esttab $Per_ben_com_est using "${table_path}/Appendix N: Reg_perception_actual_treatment_count.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title(PANEL D)

*PANEL E
esttab $Per_cont_comFaci_est using "${table_path}/Appendix N: Reg_perception_actual_treatment_count.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title(PANEL E)

*PANEL F
esttab $perception_index_est using "${table_path}/Appendix N: Reg_perception_actual_treatment_count.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title(PANEL F)

//======================================================================================================
//APPENDIX O - impact on perception average===========================================
//Treatment status - OLS
*1. only informaton treatment
eststo clear 
reg perception_average info_treat_stat if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est1

*2. information treatment and sublocation fixed effects
reg perception_average info_treat_stat i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store est2

*8. other controls 
reg perception_average info_treat_stat prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store est3

//actual treatment - OLS
*1. only informaton treatment
reg perception_average info_treat_stat_act_dum if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est4

*2. information treatment and sublocation fixed effects
reg perception_average info_treat_stat_act_dum i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store est5

*8. other controls 
reg  perception_average info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store est6

//Actual treatment - 2SLS
*1. only informaton treatment
ivregress 2sls perception_average (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est7 	

*2. information treatment and sublocation fixed effects
ivregress 2sls perception_average i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est8 	

*8. other controls 
ivregress 2sls perception_average prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est9

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
global perception_average "est1 est2 est3 est4 est5 est6 est7 est8 est9" 
esttab $perception_average using "${table_path}/Appendix O: Reg_perception_average.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) $tabOpt replace starlevels( * 0.10 ** 0.05 *** 0.010)


//======================================================================================================
//APPENDIX P - impact on perception average - actual treatment - count==================================
//OLS
*1. only informaton treatment
eststo clear 
reg perception_average info_treat_stat_act_cou if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est1 

*2. information treatment and sublocation fixed effects
reg perception_average info_treat_stat_act_cou i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store est2

*8. other controls 
reg perception_average info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store est3

//2SLS
*1. only informaton treatment
ivregress 2sls perception_average (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est4	


*2. information treatment and sublocation fixed effects
ivregress 2sls perception_average i.sublocation (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est5

*8. other controls 
ivregress 2sls perception_average prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_cou=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store est6

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab $perception_index_est using "${table_path}/Appendix P: Reg_perception_average_actual_treatment_count.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat_act_cou prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010)

//======================================================================================================
//APPENDIX R - pairwise correlation between the individual perception indicators \
cd "${table_path}" 
asdoc pwcorr Per_take_oppo Per_ben_wom Per_ben_fam Per_ben_com Per_cont_comFaci if info_treat_stat==0|info_treat_stat==1, sig replace save(Appendix_R)

//======================================================================================================
//APPENDIX S - perception (average) on posterior participation==========================================
//OLS

*1. only informaton treatment 
eststo clear 
reg post_like_part_log perception_average if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m1
*2. information treatment and sublocation fixed effects
reg post_like_part_log perception_average i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m2

*8. other controls 
reg post_like_part_log perception_average prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m3

//2SLS
*1. only informaton treatment 
ivregress 2sls post_like_part_log (perception_average=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m4

*2. information treatment and sublocation fixed effects
ivregress liml post_like_part_log i.sublocation (perception_average=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m5

*8. other controls 
ivregress liml post_like_part_log  prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (perception_average=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m6

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 m4 m5 m6 using "${table_path}/Appendix S: Reg_perception_average_on_participation.rtf", mtitle ("" "" "" "" "" "") keep (perception_average prior_like_part_log KDRDIP_heard_before_yes) order (perception_average prior_like_part_log KDRDIP_heard_before_yes) $tabOpt replace starlevels( * 0.10 ** 0.05 *** 0.010)

////==================================================================================================================
//APPENDIX T - impact of percepion on likelihood of participation=====================================================
//using information treatment take-up as an IV============================================================ 
global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
//1. only informaton treatment 
eststo clear 
ivregress 2sls post_like_part_log (perception_index=info_treat_stat_act_cou) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m1

//2. information treatment and sublocation fixed effects
ivregress 2sls post_like_part_log i.sublocation (perception_index=info_treat_stat_act_cou) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m2

//8. other controls 
ivregress liml post_like_part_log  prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (perception_index=info_treat_stat_act_cou) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m3

//Using individual information take-up as an instrument===============================================================
*1. only informaton treatment 
ivregress liml post_like_part_log (perception_index=Scrip_Under_encou_part_dummy Scrip_Under_benef_you_dummy Scrip_Under_benef_fam_dummy Scrip_Under_benef_com_dummy Scrip_Under_pho_comfac_dummy) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m4

*2. information treatment and sublocation fixed effects
ivregress liml post_like_part_log i.sublocation (perception_index=Scrip_Under_encou_part_dummy Scrip_Under_benef_you_dummy Scrip_Under_benef_fam_dummy Scrip_Under_benef_com_dummy Scrip_Under_pho_comfac_dummy) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m5

*8. other controls 
ivregress liml post_like_part_log  prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (perception_index=Scrip_Under_encou_part_dummy Scrip_Under_benef_you_dummy Scrip_Under_benef_fam_dummy Scrip_Under_benef_com_dummy Scrip_Under_pho_comfac_dummy) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m6

*PANEL A
global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 using "${table_path}/Appendix T: IVReg_perception_on_participation_information_takeup_count_individual.rtf", mtitle ("" "" "" "" "" "") keep (perception_index prior_like_part_log KDRDIP_heard_before_yes) order (perception_index prior_like_part_log KDRDIP_heard_before_yes) $tabOpt replace starlevels( * 0.10 ** 0.05 *** 0.010) title (PANEL A)

*PANEL B
esttab m4 m5 m6 using "${table_path}/Appendix T: IVReg_perception_on_participation_information_takeup_count_individual.rtf", mtitle ("" "" "" "" "" "") keep (perception_index prior_like_part_log KDRDIP_heard_before_yes) order (perception_index prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title (PANEL B)

//======================================================================================
//APPENDIX U - perception average on posterior participation============================
//2SLS using the information take-up count as an instrument
*1. only informaton treatment 
eststo clear 
ivregress 2sls post_like_part_log (perception_average=info_treat_stat_act_cou) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m1

*2. information treatment and sublocation fixed effects
ivregress 2sls post_like_part_log i.sublocation (perception_average=info_treat_stat_act_cou) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m2

*8. other controls 
ivregress liml post_like_part_log  prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (perception_average=info_treat_stat_act_cou) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m3

//2SLS (LIML) using individual information take-up as an instrument
*1. only informaton treatment 
ivregress liml post_like_part_log (perception_average=Scrip_Under_encou_part_dummy Scrip_Under_benef_you_dummy Scrip_Under_benef_fam_dummy Scrip_Under_benef_com_dummy Scrip_Under_pho_comfac_dummy) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m4

*2. information treatment and sublocation fixed effects
ivregress liml post_like_part_log i.sublocation (perception_average=Scrip_Under_encou_part_dummy Scrip_Under_benef_you_dummy Scrip_Under_benef_fam_dummy Scrip_Under_benef_com_dummy Scrip_Under_pho_comfac_dummy) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m5

*8. other controls 
ivregress liml post_like_part_log  prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (perception_average=Scrip_Under_encou_part_dummy Scrip_Under_benef_you_dummy Scrip_Under_benef_fam_dummy Scrip_Under_benef_com_dummy Scrip_Under_pho_comfac_dummy) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m6

*PANEL A
global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 using "${table_path}/Appendix U: IVReg_perception_average_on_participation_information_takeup_count_individual.rtf", mtitle ("" "" "" "" "" "") keep (perception_average prior_like_part_log KDRDIP_heard_before_yes) order (perception_average prior_like_part_log KDRDIP_heard_before_yes) $tabOpt replace starlevels( * 0.10 ** 0.05 *** 0.010) title (PANEL A)

*PANEL B
esttab m4 m5 m6 using "${table_path}/Appendix U: IVReg_perception_average_on_participation_information_takeup_count_individual.rtf", mtitle ("" "" "" "" "" "") keep (perception_average prior_like_part_log KDRDIP_heard_before_yes) order (perception_average prior_like_part_log KDRDIP_heard_before_yes) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title (PANEL B)


//=============================================================================================================
///APPENDIX V- alternative explanations - # of children and freedome of movement on participation
reg post_like_part_log child_0_6_log child_7_13_log wom_leave_home_wo_hus_perm_yes info_treat_stat KDRDIP_heard_before_yes adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat!=-1&info_treat_stat!=., cluster (sublocation)
eststo clear 
estimates store m1

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 using "${table_path}/Appendix V: Child_culture.rtf", mtitle ("" "" "" "" "" "") keep (child_0_6_log child_7_13_log wom_leave_home_wo_hus_perm_yes) $tabOpt starlevels( * 0.10 ** 0.05 *** 0.010) replace 

//=============================================================================================================
///APPENDIX W - proportion of women who can leave home without spouse's permission 

cd "${table_path}" 
*PANEL A
asdoc tab a1230, replace save(Appendix_W) title(PANEL_A)

*PANEL B 
asdoc tab a1230 if info_treat_stat==1|info_treat_stat==0, append save(Appendix_W) title(PABEL_B)

//=========================================================================================================
//APPENDIX X- additional analyses by county 
*information treatment status - OLS 
eststo clear 
foreach i in 2 3 5 {
	reg post_like_part_log info_treat_stat prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat!=-1 & county==`i', cluster (sublocation)
	est store m1_`i'
	estadd local Sublocation_FE "Yes"
	estadd local Other_controls "Yes"
}

*Actual treatment status - OLS
foreach i in 2 3 5 {
	reg post_like_part_log info_treat_stat_act_dum prior_like_part_log  KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if (info_treat_stat==1|info_treat_stat==0) & county==`i', cluster (sublocation)
	estimates store m2_`i' 
	estadd local Sublocation_FE "Yes"
	estadd local Other_controls "Yes"
}

*Actual treatment status - IV

foreach i in 2 3 5 {
	ivregress 2sls post_like_part_log prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat!=-1 & count==`i', cluster (sublocation) 
	estimates store m3_`i' 
	estadd local Sublocation_FE "Yes"
	estadd local Other_controls "Yes"
	estat firststage
}

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1_2 m2_2 m3_2 m1_3 m2_3 m3_3 m1_5 m2_5 m3_5 using "${table_path}/Appendix X: County effect.rtf", keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) s(N Sublocation_FE Other_controls) mtitle ("" "" "" "" "" "" "" "") replace $tabOpt starlevels( * 0.10 ** 0.05 *** 0.010)
