******************************************************************************************************************************************************************************************************************************************************************************************************************************************************************
//Tables and Figure==================================================================================================+
**********************************************************************************************************************

//== GLOBAL MACROS WITH RELEVANT DIRECTORIES ===========================================================================
// directories incuding data, processed tables, processed figures and other output
quietly include "`c(pwd)'/env_setup/env.do" 
assert "${data_path}" != "" & "${table_path}" != "" & "${figure_path}" != "" // should be defined

//==============================================================================================================
//reading the dataset for the figures
quietly include "`c(pwd)'/data_processing/data_processing.do" 

//==============================================================================================================
//Figure 3 - Panel A: Histogram for posterior likelihood of participation between the control and treatment group
sum post_like_part if info_treat_stat==1
local meanpost1=`r(mean)'
sum post_like_part if info_treat_stat==0
local meanpost0=`r(mean)'
twoway (hist post_like_part if info_treat_stat==1, freq width(1) fcolor(none) lcolor(blue) xline(`meanpost1', lcolor(blue) lpattern(dash))) ///
       (hist post_like_part if info_treat_stat==0, freq width(1) fcolor(none) lcolor(red) xline(`meanpost0', lcolor(red) lpattern(dash)) ///
	   ytitle("Number of women") xtitle("Likelihood of participation") ylabel(, angle(0))), ///
	   legend(order(1 "Treated" 2 "Control") tstyle(size(small)))  ///
	   graphregion(color(white))
graph export "${figure_path}/Figure 3 (PANEL A) Histogram for posterior likelihood of participation between the control and treatment group.png", replace 


//==============================================================================================================	  
//Figure 3 - Panel B: Histogram for prior likelihood of participation between the control and treatment group
tabstat prior_like_part, by (info_treat_stat)
sum prior_like_part if info_treat_stat==1
local meanprior1=`r(mean)'
sum prior_like_part if info_treat_stat==0
local meanprior0=`r(mean)'
twoway (hist prior_like_part if info_treat_stat==1, freq width(1) fcolor(none) lcolor(blue) xline(`meanprior1', lcolor(blue) lpattern(dash))) ///
       (hist prior_like_part if info_treat_stat==0, freq width(1) fcolor(none) lcolor(red) xline(`meanprior0', lcolor(red) lpattern(dash)) ///
	   ytitle("Number of women") xtitle("Likelihood of participation") ylabel(, angle(0))), ///
	   legend(order(1 "Treated" 2 "Control") tstyle(size(small))) ///
	   graphregion(color(white))
graph export "${figure_path}/Figure 3 (PANEL B) Histogram for prior likelihood of participation between the control and treatment group.png", replace


//==============================================================================================================	  
//Figure 3 - Panel C: Histogram for prior and posterior likelihood of participation for the treatment group
tabstat prior_like_part, by (info_treat_stat)
sum post_like_part if info_treat_stat==1
local meanpost1=`r(mean)'
sum prior_like_part if info_treat_stat==1
local meanprior1=`r(mean)'
twoway (hist post_like_part if info_treat_stat==1, freq width(1) fcolor(none) lcolor(blue) xline(`meanpost1', lcolor(blue) lpattern(dash))) ///
       (hist prior_like_part if info_treat_stat==1, freq width(1) fcolor(none) lcolor(red) xline(`meanprior1', lcolor(red) lpattern(dash)) ///
	   ytitle("Number of women") xtitle("Likelihood of participation") ylabel(, angle(0))), ///
	   legend(order(1 "Posterior" 2 "Prior") tstyle(size(small))) ///
	      graphregion(color(white))
graph export "${figure_path}/Figure 3 (PANEL C) Histogram for prior and posterior likelihood of participation for the treatment group.png", replace

//==============================================================================================================	  	 
//Figure 3 - Panel D: Histogram for prior and posterior likelihood of participation for the control group
tabstat prior_like_part, by (info_treat_stat)
sum post_like_part if info_treat_stat==0
local meanpost0=`r(mean)'
sum prior_like_part if info_treat_stat==0
local meanprior0=`r(mean)'
twoway (hist post_like_part if info_treat_stat==0, freq width(1) fcolor(none) lcolor(blue) xline(`meanpost0', lcolor(blue) lpattern(dash))) ///
       (hist prior_like_part if info_treat_stat==0, freq width(1) fcolor(none) lcolor(red) xline(`meanprior0', lcolor(red) lpattern(dash)) ///
	   ytitle("Number of women") xtitle("Likelihood of participation") ylabel(, angle(0))), ///
	   legend(order(1 "Posterior" 2 "Prior") tstyle(size(small))) ///
	      graphregion(color(white))
graph export "${figure_path}/Figure 3 (PANEL D) Histogram for prior and posterior likelihood of participation for the control group.png", replace
		  
//======================================================================================================================
//TABLE 1 - DID
*read and processing the data for the simple DID table. The results will be displayed in the results panel.    
quietly include "`c(pwd)'/data_processing/data_processing.do" 
rename post_like_part like_part1
rename prior_like_part like_part0
keep info_treat_stat like_part1 like_part0 KEY
reshape long like_part, i(KEY) j(post)
sum
drop if info_treat_stat!=1 & info_treat_stat!=0
sum

cap which ietoolkit 
if _rc ssc install ietoolkit
ieddtab like_part, time( post ) treatment( info_treat_stat)

//======================================================================================================================
//read and processing the data for the rest of the tables 
quietly include "`c(pwd)'/data_processing/data_processing.do" 	 
	   //===================================================================================================================		 //Table 2- regression models; treatment status
//1. only informaton treatment
*if _rc ssc install estout 
*ssc install estout

reg post_like_part_log info_treat_stat if info_treat_stat!=-1, cluster (sublocation)
estimates store m1
estadd local Sublocation_FE "No"
estadd local Other_controls "No"

//2. information treatment and sublocation fixed effects
reg post_like_part_log info_treat_stat i.sublocation if info_treat_stat!=-1, cluster (sublocation)
estimates store m2 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//3.information treatment, sublocation fixed effects, and prior likelihood of participation
reg post_like_part_log info_treat_stat prior_like_part_log i.sublocation if info_treat_stat!=-1, cluster (sublocation)
estimates store m3 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//4. information treatment, sublocation fixed effects, prior likelihood of participation, and interaction between prior particpation and treatment
reg post_like_part_log info_treat_stat prior_like_part_log treatment_prior_like_part_log i.sublocation if info_treat_stat!=-1, cluster (sublocation)
estimates store m4 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//5. information treatment, sublocation fixed effects, and heard before
reg post_like_part_log info_treat_stat KDRDIP_heard_before_yes i.sublocation if info_treat_stat!=-1, cluster (sublocation)
estimates store m5 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//6. information treatment, sublocation fixed effects, heard before, and interaction between treatment and heard before
reg post_like_part_log info_treat_stat KDRDIP_heard_before_yes treatment_heard_before i.sublocation if info_treat_stat!=-1, cluster (sublocation)
estimates store m6 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//7. information treatment, sublocation fixed effects, heard before, interaction between treatment and heard before, prior likelihood of particpiation, and interaction between treatment and prior likelihood of participation
reg post_like_part_log info_treat_stat prior_like_part_log treatment_prior_like_part_log KDRDIP_heard_before_yes treatment_heard_before i.sublocation if info_treat_stat!=-1, cluster (sublocation)
estimates store m7 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//8. other controls 
reg post_like_part_log info_treat_stat prior_like_part_log treatment_prior_like_part_log KDRDIP_heard_before_yes treatment_heard_before child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat!=-1, cluster (sublocation)
estimates store m8 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "Yes"

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "${table_path}/Table 2 Regression_posterior_likelihood of particpation_treatment1.rtf", keep (info_treat_stat prior_like_part_log treatment_prior_like_part_log KDRDIP_heard_before_yes treatment_heard_before) s(N Sublocation_FE Other_controls) mtitle ("" "" "" "" "" "" "" "") replace $tabOpt starlevels( * 0.10 ** 0.05 *** 0.010)

//=====================================================================================================================	
//Table 3 - regression models; information treatment
//1. only informaton treatment 
reg post_like_part_log info_treat_stat_act_dum if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m1
estadd local Sublocation_FE "No"
estadd local Other_controls "No"


//2. information treatment and sublocation fixed effects
reg post_like_part_log info_treat_stat_act_dum i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m2 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//3.information treatment, sublocation fixed effects, and prior likelihood of participation
reg post_like_part_log info_treat_stat_act_dum prior_like_part_log i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m3 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"


//4. information treatment, sublocation fixed effects, prior likelihood of participation, and interaction between prior particpation and treatment
reg post_like_part_log info_treat_stat_act_dum prior_like_part_log ac_treatment_prior_like_part_log i.sublocation if info_treat_stat==1|info_treat_stat==0, cluster (sublocation)
estimates store m4 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//5. information treatment, sublocation fixed effects, and heard before
reg post_like_part_log info_treat_stat_act_dum KDRDIP_heard_before_yes i.sublocation if info_treat_stat==1|info_treat_stat==0, cluster (sublocation)
estimates store m5 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"


//6. information treatment, sublocation fixed effects, heard before, and interaction between treatment and heard before
reg post_like_part_log info_treat_stat_act_dum KDRDIP_heard_before_yes ac_treatment_heard_before i.sublocation if info_treat_stat==1|info_treat_stat==0, cluster (sublocation)
estimates store m6
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

//7. information treatment, sublocation fixed effects, heard before, interaction between treatment and heard before, prior likelihood of particpiation, and interaction between treatment and prior likelihood of participation
reg post_like_part_log info_treat_stat_act_dum prior_like_part_log ac_treatment_prior_like_part_log KDRDIP_heard_before_yes ac_treatment_heard_before i.sublocation if info_treat_stat==1|info_treat_stat==0, cluster (sublocation)
estimates store m7 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"


//8. other controls 
reg post_like_part_log info_treat_stat_act_dum prior_like_part_log ac_treatment_prior_like_part_log KDRDIP_heard_before_yes ac_treatment_heard_before child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==1|info_treat_stat==0, cluster (sublocation)
estimates store m8 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "${table_path}/Table 3 Regression_posterior_likelihood of particpation_actual treatment.rtf", keep (info_treat_stat_act_dum prior_like_part_log ac_treatment_prior_like_part_log KDRDIP_heard_before_yes ac_treatment_heard_before) s(N Sublocation_FE Other_controls) mtitle ("" "" "" "" "" "" "" "") replace $tabOpt starlevels( * 0.10 ** 0.05 *** 0.010)


//===================================================================================================================
//TABLE 4 - Iv regression
*if _rc ssc install ivreg2
*ssc install ivreg2

*if _rc ssc install ranktest
*ssc install ranktest

eststo clear 
//1. only informaton treatment 
/*ivregress 2sls post_like_part_log (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m1
estadd local Sublocation_FE "No"
estadd local Other_controls "No"
*/
xi:ivreg2 post_like_part_log (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation) first savefirst
estimates store m1
estadd local Sublocation_FE "No"
estadd local Other_controls "No"
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

//2. information treatment and sublocation fixed effects
/*ivregress 2sls post_like_part_log i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation)
estimates store m2 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
*/
xi: ivreg2 post_like_part_log i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation) first savefirst
estimates store m2 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)


//3.information treatment, sublocation fixed effects, and prior likelihood of participation
/*ivregress 2sls post_like_part_log prior_like_part_log i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m3
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
*/
xi: ivreg2 post_like_part_log prior_like_part_log i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat!=-1, cluster (sublocation) first savefirst
estimates store m3
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

//4. information treatment, sublocation fixed effects, prior likelihood of participation, and interaction between prior particpation and treatment
/*ivregress 2sls post_like_part_log prior_like_part_log i.sublocation (info_treat_stat_act_dum ac_treatment_prior_like_part_log=info_treat_stat treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m4
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
*/

xi: ivreg2 post_like_part_log prior_like_part_log i.sublocation (info_treat_stat_act_dum ac_treatment_prior_like_part_log=info_treat_stat treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) first savefirst
estimates store m4
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar AveShea= (fstat[2,1]+fstat[2,2])/2
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

//5. information treatment, sublocation fixed effects, and heard before
/*
ivregress 2sls post_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_dum=info_treat_stat ) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m5
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
*/

xi: ivreg2 post_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_dum=info_treat_stat ) if info_treat_stat!=-1, cluster (sublocation) first savefirst
estimates store m5
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

//6. information treatment, sublocation fixed effects, heard before, and interaction between treatment and heard before
/*ivregress 2sls post_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_dum ac_treatment_heard_before=info_treat_stat treatment_heard_before) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m6
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
*/

xi: ivreg2 post_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_dum ac_treatment_heard_before=info_treat_stat treatment_heard_before) if info_treat_stat!=-1, cluster (sublocation) first savefirst
estimates store m6
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar AveShea= (fstat[2,1]+fstat[2,2])/2
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

//7. information treatment, sublocation fixed effects, heard before, interaction between treatment and heard before, prior likelihood of particpiation, and interaction between treatment and prior likelihood of participation
/*ivregress 2sls post_like_part_log prior_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_dum ac_treatment_heard_before ac_treatment_prior_like_part_log=info_treat_stat treatment_heard_before treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m7
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
*/

xi: ivreg2 post_like_part_log prior_like_part_log KDRDIP_heard_before_yes i.sublocation (info_treat_stat_act_dum ac_treatment_heard_before ac_treatment_prior_like_part_log=info_treat_stat treatment_heard_before treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) first savefirst  
estimates store m7
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar AveShea= (fstat[2,1]+fstat[2,2]+fstat[2,3])/3
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

//8. other controls 
/*ivregress 2sls post_like_part_log prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_dum ac_treatment_heard_before ac_treatment_prior_like_part_log=info_treat_stat treatment_heard_before treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) 
estimates store m8
estadd local Sublocation_FE "Yes", replace   
estadd local Other_controls "Yes", replace 
*/

xi: ivreg2 post_like_part_log prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_dum ac_treatment_heard_before ac_treatment_prior_like_part_log=info_treat_stat treatment_heard_before treatment_prior_like_part_log) if info_treat_stat!=-1, cluster (sublocation) first savefirst  
estimates store m8
estadd local Sublocation_FE "Yes", replace   
estadd local Other_controls "Yes", replace 
. mat list e(first)
mat fstat = e(first)
estadd scalar AveShea= (fstat[2,1]+fstat[2,2]+fstat[2,3])/3
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "${table_path}/Table 4 IVregression_posterior_likelihood of particpation_actual treatment.rtf", keep (info_treat_stat_act_dum prior_like_part_log ac_treatment_prior_like_part_log KDRDIP_heard_before_yes ac_treatment_heard_before) s(F_stat AveShea Under Weak N Sublocation_FE Other_controls, label ("F(1.48)" "Average adjusted shea R2" "Underindetification test (Kleibergen-Paap rk LM statistic)" "Weak identification test(Kleibergen-Paap rk Wald F statistic)" "N" "Sublocation fixed effects" "Other controls")) mtitle ("" "" "" "" "" "" "" "") replace $tabOpt starlevels( * 0.10 ** 0.05 *** 0.010)


//===============================================================================================================
//TABLE 5 - impact on perception=================================================================================
//OLS - Treatment status
*1. only informaton treatment
eststo clear 
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat if info_treat_stat!=-1, cluster (sublocation)
estimates store `var'_BOT
estadd local Sublocation_FE "No"
estadd local Other_controls "No" 
}

*2. information treatment and sublocation fixed effects
eststo clear
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat i.sublocation if info_treat_stat!=-1, cluster (sublocation)	
estimates store `var'_SOT
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
}

*8. other controls 
eststo clear
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat!=-1, cluster (sublocation)	
estimates store `var'_OOT
estadd local Sublocation_FE "Yes"
estadd local Other_controls "Yes"
}

//OLS - actual treatment 
*1. only informaton treatment
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat_act_dum if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store `var'_BOAT
estadd local Sublocation_FE "No"
estadd local Other_controls "No" 
}

*2. information treatment and sublocation fixed effects
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat_act_dum i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store `var'_SOAT
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
}

*8. other controls 
foreach var in $perception_log_perception_index {
reg `var' info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store `var'_OOAT
estadd local Sublocation_FE "Yes"
estadd local Other_controls "Yes"
}

//2SLS - actual treatment
//1. only informaton treatment
/*
foreach var in $perception_log_perception_index {
ivregress 2sls `var' (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store `var'_BIV 	
}
*/

foreach var in $perception_log_perception_index {
xi: ivreg2 `var' (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) first savefirst 
estimates store `var'_BIV 
estadd local Sublocation_FE "No"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)
}

//2. information treatment and sublocation fixed effects
/*
foreach var in $perception_log_perception_index {
ivregress 2sls `var' i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)	
estimates store `var'_SIV

}
*/

foreach var in $perception_log_perception_index {
xi: ivreg2 `var' i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) partial (i.sublocation) first savefirst 
estimates store `var'_SIV 
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)	
}

//8. other controls 
/*
foreach var in $perception_log_perception_index {
ivregress 2sls `var' prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store `var'_OIV	
}
*/

foreach var in $perception_log_perception_index {
xi: ivreg2 `var' prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (info_treat_stat_act_dum=info_treat_stat) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) first savefirst
estimates store `var'_OIV
estadd local Sublocation_FE "Yes"
estadd local Other_controls "Yes"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)	
}

global Per_take_oppo_est "Per_take_oppo_log_BOT Per_take_oppo_log_SOT Per_take_oppo_log_OOT Per_take_oppo_log_BOAT Per_take_oppo_log_SOAT Per_take_oppo_log_OOAT Per_take_oppo_log_BIV Per_take_oppo_log_SIV Per_take_oppo_log_OIV"

global Per_ben_wom_est "Per_ben_wom_log_BOT Per_ben_wom_log_SOT Per_ben_wom_log_OOT Per_ben_wom_log_BOAT Per_ben_wom_log_SOAT Per_ben_wom_log_OOAT Per_ben_wom_log_BIV Per_ben_wom_log_SIV Per_ben_wom_log_OIV"

global Per_ben_fam_est "Per_ben_fam_log_BOT Per_ben_fam_log_SOT Per_ben_fam_log_OOT Per_ben_fam_log_BOAT Per_ben_fam_log_SOAT Per_ben_fam_log_OOAT Per_ben_fam_log_BIV Per_ben_fam_log_SIV Per_ben_fam_log_OIV"

global Per_ben_com_est "Per_ben_com_log_BOT Per_ben_com_log_SOT Per_ben_com_log_OOT Per_ben_com_log_BOAT Per_ben_com_log_SOAT Per_ben_com_log_OOAT Per_ben_com_log_BIV Per_ben_com_log_SIV Per_ben_com_log_OIV"

global Per_cont_comFaci_est "Per_cont_comFaci_log_BOT Per_cont_comFaci_log_SOT Per_cont_comFaci_log_OOT Per_cont_comFaci_log_BOAT Per_cont_comFaci_log_SOAT Per_cont_comFaci_log_OOAT Per_cont_comFaci_log_BIV  Per_cont_comFaci_log_SIV Per_cont_comFaci_log_OIV"

global perception_index_est "perception_index_BOT perception_index_SOT perception_index_OOT perception_index_BOAT perception_index_SOAT perception_index_OOAT perception_index_BIV perception_index_SIV perception_index_OIV"


*PANEL A
global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab $Per_take_oppo_est using "${table_path}/Table 5 impact on perception.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) noobs $tabOpt replace starlevels( * 0.10 ** 0.05 *** 0.010) title ("PANEL A")

*PANEL B
global tabOpt "b(4) se(3) not nogaps compress varwidth(10) label nonote"
esttab $Per_ben_wom_est using "${table_path}/Table 5 impact on perception.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) noobs $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title ("PANEL B")

*PANEL C
global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab $Per_ben_fam_est using "${table_path}/Table 5 impact on perception.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) noobs $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title ("PANEL C")

*PANEL D
global tabOpt "b(4) se(3) not nogaps compress varwidth(10) label nonote"
esttab $Per_ben_com_est using "${table_path}/Table 5 impact on perception.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) noobs $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title ("PANEL D")

*PANEL E
global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab $Per_cont_comFaci_est using "${table_path}/Table 5 impact on perception.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) noobs $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title ("PANEL E")

*PANEL F
global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab $perception_index_est using "${table_path}/Table 5 impact on perception.rtf", mtitle ("" "" "" "" "" "" "" "" "") keep (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) order (info_treat_stat info_treat_stat_act_dum prior_like_part_log KDRDIP_heard_before_yes) s(F_stat Under Weak N Sublocation_FE Other_controls, label ("F(1.48)" "Underindetification test (Kleibergen-Paap rk LM statistic)" "Weak identification test(Kleibergen-Paap rk Wald F statistic)" "N" "Sublocation fixed effects" "Other controls")) $tabOpt append starlevels( * 0.10 ** 0.05 *** 0.010) title ("PANEL F")

//===============================================================================================================
//TABLE 6- perception on posterior participation - perception index==============================================
//OLS
eststo clear
*1. only informaton treatment 
reg post_like_part_log perception_index if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m1
estadd local Sublocation_FE "No"
estadd local Other_controls "No"

*2. information treatment and sublocation fixed effects
reg post_like_part_log perception_index i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m2
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"

*8. other controls 
reg post_like_part_log perception_index prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m3
estadd local Sublocation_FE "Yes"
estadd local Other_controls "Yes"


//2sls
*1. only informaton treatment 
/*ivregress 2sls post_like_part_log (perception_index=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m4
*/
ivreg2 post_like_part_log (perception_index=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) first savefirst 
estimates store m4
estadd local Sublocation_FE "No"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

*2. information treatment and sublocation fixed effects
/*ivregress 2sls post_like_part_log i.sublocation (perception_index=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) 
estimates store m5*/

xi: ivreg2 post_like_part_log i.sublocation (perception_index=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) first savefirst
estimates store m5
estadd local Sublocation_FE "Yes"
estadd local Other_controls "No"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

*8. other controls 
/*ivregress liml post_like_part_log  prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (perception_index=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation)
estimates store m6

*/

xi:ivreg2 post_like_part_log  prior_like_part_log KDRDIP_heard_before_yes child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 women_25_60_educ_mean women_25_60_age_mean women_25_60_atte_scho_num women_25_60_housewif_num i.sublocation (perception_index=info_treat_stat_act_dum) if info_treat_stat==0|info_treat_stat==1, cluster (sublocation) first savefirst
estimates store m6
estadd local Sublocation_FE "Yes"
estadd local Other_controls "Yes"
. mat list e(first)
mat fstat = e(first)
estadd scalar F_stat = fstat[4,1] 
estadd scalar Under= e(idstat) 
estadd scalar Weak= e(widstat)

global tabOpt "b(3) se(3) not nogaps compress varwidth(10) label nonote"
esttab m1 m2 m3 m4 m5 m6 using "${table_path}/Table 6 Reg_perception_on_participation.rtf", mtitle ("" "" "" "" "" "") keep (perception_index prior_like_part_log KDRDIP_heard_before_yes) order (perception_index prior_like_part_log KDRDIP_heard_before_yes) coeflabels(perception_index "Overall perception index")  $tabOpt replace starlevels( * 0.10 ** 0.05 *** 0.010) s(F_stat Under Weak N Sublocation_FE Other_controls, label ("F(1.48)" "Underindetification test (Kleibergen-Paap rk LM statistic)" "Weak identification test(Kleibergen-Paap rk Wald F statistic)" "N" "Sublocation fixed effects" "Other controls"))

